pub struct Usage {
pub input_tokens: u32,
pub output_tokens: u32,
pub prompt_cache_hit_tokens: Option<u32>,
pub prompt_cache_miss_tokens: Option<u32>,
pub reasoning_tokens: Option<u32>,
pub reasoning_replay_tokens: Option<u32>,
pub server_tool_use: Option<ServerToolUsage>,
}Expand description
Token usage metadata for a response.
Fields
input_tokens: u32output_tokens: u32prompt_cache_hit_tokens: Option<u32>prompt_cache_miss_tokens: Option<u32>reasoning_tokens: Option<u32>reasoning_replay_tokens: Option<u32>Approximate input tokens spent re-sending prior reasoning_content
across user-message boundaries (V4 5.1.1 “Interleaved Thinking”).
server_tool_use: Option<ServerToolUsage>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Usage
impl<'de> Deserialize<'de> for Usage
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Usage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Usage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Usage
Sourceimpl JsonSchema for Usage
impl JsonSchema for Usage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for Usage
impl Serialize for Usage
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Usage