Small shared helpers for adapters modules.
Functions
- write_
atomic - Write
contentstopathatomically via a temp file in the same directory.
Small shared helpers for adapters modules.
contents to path atomically via a temp file in the same directory.